@@ -14,6 +14,7 @@
 #####################################################################
 
 import time
+import json
 import requests
 import gzip
 import socket
@@ -79,7 +80,7 @@ def check_connectivity( ) :
         try :
 
             host = socket.gethostbyname( endpoint_parseurl.hostname ) 
-            s = socket.create_connection( ( host , endpoint_url_port ) , 30 )
+            s = socket.create_connection( ( host , endpoint_url_port ) , 10 )
             s.close( )
 
         except Exception as e :
@@ -88,10 +89,14 @@ def check_connectivity( ) :
 
     ################################################################
 
+    s_config.set_key_alt( "endpoint/timeout" , 10 ) ;
+
     if( flag_networkok and get_request_response( { "X-Omni-Action": "check_connectivity" } ) == False ) :
         s_log.write( "False check_connectivity 2" )
         flag_networkok = False
 
+    s_config.del_key_alt( "endpoint/timeout" ) ;
+
     ################################################################
 
     check_connectivity_done = flag_networkok
@@ -111,9 +116,9 @@ def check_connectivity( ) :
 
 def job_request( ) :
 
-    if( not s_util.ready( ) ) :
-        s_log.write( "NOT READY" )
-        return( False )
+    #if( not s_util.ready( ) ) :
+    #    s_log.write( "NOT READY" )
+    #    return( False )
 
     #####################################################################
 
@@ -156,9 +161,9 @@ def job_request( ) :
 
 def job_responsewait( jid , timeout = 60 ) :
 
-    if( not s_util.ready( ) ) :
-        s_log.write( "NOT READY" )
-        return( False )
+    #if( not s_util.ready( ) ) :
+    #    s_log.write( "NOT READY" )
+    #    return( False )
         
     #####################################################################
 
@@ -171,14 +176,13 @@ def job_responsewait( jid , timeout = 60 ) :
         if( jr == False ) : return( False )
         if( jr == True ) : return( True )
         if( time.time( ) - time_start ) > timeout : return( None )
+        time.sleep( 1 )
 
 def job_response( jid ) :
 
-    time.sleep( 1 )
-
-    if( not s_util.ready( ) ) :
-        s_log.write( "NOT READY" )
-        return( False )
+    #if( not s_util.ready( ) ) :
+    #    s_log.write( "NOT READY" )
+    #    return( False )
         
     #####################################################################
 
@@ -218,9 +222,9 @@ def job_response( jid ) :
 
 def job_get( ) :
 
-    if( not s_util.ready( ) ) :
-        s_log.write( "NOT READY" )
-        return( False )
+    #if( not s_util.ready( ) ) :
+    #    s_log.write( "NOT READY" )
+    #    return( False )
 
     #####################################################################
 
@@ -250,10 +254,12 @@ def job_get( ) :
     if( "X-Omni-Context" in res.headers ) :
         #s_log.write( "Found X-Omni-Context" )
         #s_log.write( res.headers[ "X-Omni-Context" ] )
-        s_log.write( "FIXME TODO context json to meta add" )
+        #s_log.write( "FIXME TODO context json to meta add" )
 #        context_json = base64.b64decode( res.headers[ "X-Omni-Context" ] ).decode( "utf-8" )
         context_json = s_util.base64_decode( res.headers[ "X-Omni-Context" ] )
-        #s_db.meta_create( "_server_getjob_context_json" , context_json ) 
+        context=json.loads(context_json)
+        #s_db.meta_create( "_context" , context_json ) 
+        s_config.set_key( "header_context" , context ) 
 
     job_id = res.headers[ "X-Omni-Jid" ]
     s_config.set_key( "jid" , job_id ) 
@@ -263,9 +269,9 @@ def job_get( ) :
 
 def job_set( ) :
 
-    if( not s_util.ready( ) ) :
-        s_log.write( "NOT READY" )
-        return( False )
+    #if( not s_util.ready( ) ) :
+    #    s_log.write( "NOT READY" )
+    #    return( False )
 
     #####################################################################
 
@@ -278,7 +284,7 @@ def job_set( ) :
     db_filecontents = s_db.file_contents( )
 
     payload = gzip.compress( db_filecontents  )
-    payload_size = len( payload )
+    #payload_size = len( payload )
     #s_log.write("YYY "+str(payload_size))
 
     #####################################################################
@@ -309,10 +315,14 @@ def job_set( ) :
 
 def get_request_response( request_headers = { }  , payload = "" ) :
 
+    time.sleep( 0.1 )
+
     if not "User-Agent" in request_headers :
         request_headers[ "User-Agent" ] = "sapiadapter"
     if not "X-Omni-Authorization" in request_headers :
-        request_headers[ "X-Omni-Authorization" ] = s_config.get_key( "endpoint/token" ) 
+        token=s_config.get_key( "endpoint/token" )
+        if( token != False ) :
+            request_headers[ "X-Omni-Authorization" ] = s_config.get_key( "endpoint/token" ) 
 
     endpoint_host = s_config.get_key( "endpoint/host" )
     if endpoint_host != None and endpoint_host != "" :
@@ -338,10 +348,12 @@ def get_request_response( request_headers = { }  , payload = "" ) :
     ################################################################ 
 
     endpoint_timeout = s_config.get_key( "endpoint/timeout" )
-    if endpoint_timeout == None or ( not endpoint_timeout.isdigit( ) ) :
-        endpoint_timeout = 180
-    else:
-        endpoint_timeout = int( endpoint_timeout )
+
+    if( isinstance( endpoint_timeout , str ) ) :
+        if endpoint_timeout == None or ( not endpoint_timeout.isdigit( ) ) :
+            endpoint_timeout = 180
+        else:
+            endpoint_timeout = int( endpoint_timeout )
 
     endpoint_url = s_config.get_key( "endpoint/url" ) 
     if( not endpoint_url ) :
@@ -361,6 +373,7 @@ def get_request_response( request_headers = { }  , payload = "" ) :
         response = session.post( endpoint_url , data = payload , headers = request_headers , timeout = endpoint_timeout , verify = endpoint_sslverify )
 
     except requests.exceptions.SSLError as e :
+        s_log.write( endpoint_url )
         s_log.write( "ERROR requests.exceptions.SSLError:" + str( e ) )
         return( False )    
     except requests.exceptions.ReadTimeout as e :
